```{warning}
Snakebids is migrating to a more robust, extensible API! If you're coming from pre-v0.8 code, check out the [migration guide](/migration/0.7_to_0.8) to ensure your workflow is up-to-date.
```

```{include} ../README.md
```


```{toctree}
:caption: User Guide
:name: guide
:hidden:
:maxdepth: 1

general/why_snakebids
tutorial/tutorial
bids_function/overview

bids_app/overview

running_snakebids/overview

migration/index
```





```{toctree}
:caption: Reference
:hidden:
:maxdepth: 2

api/main
api/internals
api/plugins
```
